<?php

namespace Tal;

/**
 * Class Server
 *
 * @package Tal
 * @author Thomas Flori <thflori@gmail.com>
 */
class Server
{
    public static function getHost()
    {
        if (isset($_SERVER['HTTP_HOST'])) {
            $hostHeaderParts = explode(':', $_SERVER['HTTP_HOST']);
            return $hostHeaderParts[0];
        }

        if (isset($_SERVER['SERVER_NAME'])) {
            return $_SERVER['SERVER_NAME'];
        }

        if (isset($_SERVER['SERVER_ADDR'])) {
            return $_SERVER['SERVER_ADDR'];
        }

        return null;
    }

    public static function getPort()
    {
        if (isset($_SERVER['HTTP_HOST']) && strpos($_SERVER['HTTP_HOST'], ':') !== false) {
            return explode(':', $_SERVER['HTTP_HOST'])[1];
        }

        if (isset($_SERVER['SERVER_PORT'])) {
            return $_SERVER['SERVER_PORT'];
        }

        return null;
    }

    public static function getPath()
    {
        if (isset($_SERVER['REQUEST_URI'])) {
            $requestUriParts = explode('?', $_SERVER['REQUEST_URI']);
            return $requestUriParts[0];
        }

        return null;
    }

    public static function getQuery()
    {
        if (isset($_SERVER['REQUEST_URI']) && strpos($_SERVER['REQUEST_URI'], '?') !== false) {
            return explode('?', $_SERVER['REQUEST_URI'])[1];
        }

        if (isset($_SERVER['QUERY_STRING'])) {
            return $_SERVER['QUERY_STRING'];
        }

        return null;
    }

    /**
     * Send a raw HTTP header
     *
     * @link http://php.net/manual/en/function.header.php
     * @param string $string The header string
     * @param bool $replace
     * @param int $responseCode
     * @return void
     * @codeCoverageIgnore trivial wrapper
     */
    public function header($string, $replace = true, $responseCode = null)
    {
        header($string, $replace, $responseCode);
    }

    /**
     * Echos the given $string
     *
     * @param $string
     * @return void
     * @codeCoverageIgnore trivial wrapper
     */
    public function echo($string)
    {
        echo($string);
    }
}
